@@ -2,5 +2,5 @@ from bolinette.console import Console, console
 from bolinette.bcrypt import bcrypt
 import bolinette.defaults
 import bolinette.init
-from bolinette.commands import command
+import bolinette.commands
 from bolinette.bolinette import Bolinette
